@@ -1,7 +1,7 @@
   # -*- coding: utf-8 -*-
 
 ask = 'ghost'
-inp = 100
+inp = 0
 feel = 'good'
 stob = [0, 1 , 2 , 3 , 4]
 stog = [6 , 7 , 8 , 9]
@@ -11,7 +11,7 @@ def emotion (ask, url) :
   from firebase import firebase
   firebase = firebase.FirebaseApplication(url, None)
 
-  inp = 'dont know'
+  inp = 100
 
   ovalue = firebase.get('/oi', None)
   ovalue = str(ovalue).replace('None, ', '')
@@ -32,13 +32,15 @@ def emotion (ask, url) :
     if ask == compare[0]:
       inp = int(compare[1])
 
-  moodG = ovalue.count('10')
-  moodB = ovalue.count('0')
-
   knowb = bad = sum(stob)/len(stob)
   knowg = good = sum(stog)/len(stog)
 
-  
+  moodG = ovalue.count('10')
+  moodB = ovalue.count('0')
+
+
+
+
   if moodG < moodB :
     ovimo = 'Frustrated'
 
@@ -81,7 +83,7 @@ def emotion (ask, url) :
   if inp == 5 :
     feel = 'nothing'
 
-  if inp == 'dont know':
+  if inp == 100:
     val = input("Sorry I don't know about" + inp + " ,but I am Curious about it Can you please tell me, How you feel about it? (give the answer in 'angry','sad','scared','excited','happy','h-cited','nothing' :   "   )
     l = val.lower()
     if l == 'angry':
@@ -119,15 +121,40 @@ def emotion (ask, url) :
   emotion.feelings = 'I am feeling '+ feel+ ' about ' + ask
   emotion.mood = 'mood:'+ ovimo
 
-def learn (input, feel, url) :
-  
-  knoutings= input
+def learn (input, emotion, url):
+
+  l = input
+
+
+  if l == 'angry':
+    kit = 4
+    print('Thanks!')
+  if l == 'sad':
+    kit = 2.0
+    print('Thanks!')
+  if l == 'scared':
+    kit = 0
+    print('Thanks!')
+  if l == 'excited':
+    kit = 8
+    print('Thanks!')
+  if l == 'happy':
+    kit = 6
+    print('Thanks!')
+  if l == 'h-cited':
+    kit = 7.5
+    print('Thanks!')
+  if l == 'nothing':
+    kit = 5
+    print('Thanks!')
+
+  knoutings = kit
   emI = emotion
   from firebase import firebase
   firebase = firebase.FirebaseApplication(url, None)
-  firebase.put('/knowlage',knoutings,emI)
+  firebase.put('/knowlage', knoutings, emI)
 
-  count = firebase.get('/count',None)
+  count = firebase.get('/count', None)
   count = str(count).replace('None, ', '')
   count = str(count).replace('[', '')
   count = str(count).replace(']', '')
@@ -135,12 +162,13 @@ def learn (input, feel, url) :
 
   count2 = int(count) + 1
 
-  firebase.put('/count','1',count2)
+  firebase.put('/count', '1', count2)
 
-  print(count2)
+  print('Got it!')
 
   if emI == 0 or 1 or 2 or 3 or 4:
-    firebase.put('/oi',count2,0)
+    firebase.put('/oi', count2, 0)
+
+  if emI == 6 or 7.5 or 8 or 9 or 10:
+    firebase.put('/oi', count2, 10)
 
-  else:
-    firebase.put('/oi',count2,10)
\ No newline at end of file
